@@ -26,17 +26,37 @@ fetch_entry_chemical_shifts<-function(BMRBidlist){
       else{
         csdata<-data.table::as.data.table(y$data)
         cstags<-as.data.frame(data.table::as.data.table(y$tags))$V1
-        if (exists('cs_data')){
-          cs_data<-rbind(cs_data,as.data.frame(data.table::data.table(t(csdata))))}
+        csdata<-as.data.frame(data.table::data.table(t(csdata)))
+        colnames(csdata)<-cstags
+        if (!("Entry_ID" %in% colnames(csdata))){
+          csdata$Entry_ID = makeRandomString()
+        }
+        if (!("Comp_index_ID" %in% colnames(csdata)) & ("Seq_ID" %in% colnames(csdata)) ){
+          csdata$Comp_index_ID = csdata$Seq_ID
+        }
+        if (!("Entity_ID" %in% colnames(csdata))){
+          csdata$Entity_ID=1
+        }
+        if (!("Assigned_chem_shift_list_ID" %in% colnames(csdata))){
+          csdata$Assigned_chem_shift_list_ID=1
+        }
+        if (exists('cs_data') & exists('csdata')){
+          if (length(colnames(cs_data)) != length(colnames(csdata))){
+            common_col<-intersect(colnames(cs_data),colnames(csdata))
+            cs_data<-subset(cs_data,select=common_col)
+            csdata<-subset(csdata,select=common_col)
+            warning("Entries have differnet columns;mismatch will be removed")
+          }
+          cs_data<-rbind(cs_data,csdata)}
         else{
-          cs_data<-as.data.frame(data.table::data.table(t(csdata)))}
+          cs_data<-csdata}
         }
       }
     }
     if (exists('cs_data')){
-      colnames(cs_data)<-cstags
       cs_data$Val<-suppressWarnings(as.numeric(cs_data$Val))
-      cs_data$Val_err<-suppressWarnings(as.numeric(cs_data$Val_err))}
+      cs_data$Val_err<-suppressWarnings(as.numeric(cs_data$Val_err))
+      }
     else{
       warning('No data')
       cs_data<-NA}
@@ -45,9 +65,56 @@ fetch_entry_chemical_shifts<-function(BMRBidlist){
     warning('Entry not found')
     cs_data<-NA
   }
+
   return (cs_data)
 }
 
+#'Generates random string of fixed length(for internal use in RBMRB)
+#'
+#'Local files may not have Entry_ID, in that case random Entry_ID is assigned using this function. It is an internal function used only by RBMRB package
+makeRandomString <- function()
+{
+  n = 1
+  lenght = 6
+  randomString <- c(1:n)                  # initialize vector
+  for (i in 1:n)
+  {
+    randomString[i] <- paste(sample(c(0:9, letters, LETTERS),
+                                    lenght, replace=TRUE),
+                             collapse="")
+  }
+  return(randomString)
+}
+
+
+#'Exports NMR-STAR file to BMRB API server
+#'
+#'Exports NMR-STAR file to BMRB API server, so that local data can be visualized using RBMRB library. This function will return a tocken, which can be used to access the data through RBMRB package. The tocken will expire after 7 days
+#'@param filename filename with correct path
+#'@return Temporary tocken to access the file
+#'@export export_star_data
+#'@examples
+#'# ent_id <- export_star_data('/nmrdata/hpr.str')
+#'# Exports hpr.str file to BMRB API server and gets a temporary tocken
+#'@seealso \code{\link{fetch_atom_chemical_shifts}}, \code{\link{fetch_entry_chemical_shifts}} \code{\link{fetch_res_chemical_shifts}}
+export_star_data<-function(filename){
+  bmrb_apiurl_json<-"http://webapi.bmrb.wisc.edu/v1/jsonrpc"
+  query=rjson::toJSON(list(method='store',jsonrpc='2.0',params=list(data=readChar(filename, file.info(filename)$size)),id=1))
+  rawdata<-httr::POST(bmrb_apiurl_json,encode='json',body=query)
+  c<-rjson::fromJSON(httr::content(rawdata,'text',encoding = 'UTF-8'))
+  if (length(c$result)!=0){
+    ent_id<-c$result$entry_id
+    print(paste("Please note down the ID",ent_id,sep=":"))
+    print(paste("ID will expire on ", as.POSIXct(c$result$expiration, origin = "1970-01-01"),sep=" "))
+  }
+  else{
+    warning('Entry not found')
+    ent_id<-NA
+  }
+  return (ent_id)
+}
+
+
 #'Fetchs atom specific NMR chemical shift data from BMRB database
 #'
 #'Downloads the full list of chemical shifts from BMRB macromolecular/metabolomics database for a given atom
